@@ -77,7 +77,7 @@ struct _AtkRoleItem
   gchar   *name;
 };
 
-static AtkRoleItem role_items [] =
+static const AtkRoleItem role_items [] =
 {
   { ATK_ROLE_INVALID, N_("invalid")},
   { ATK_ROLE_ACCEL_LABEL, N_("accelerator label")},
@@ -216,21 +216,21 @@ static guint atk_object_signals[LAST_SIGNAL] = { 0, };
 
 static gpointer parent_class = NULL;
 
-static const gchar* atk_object_name_property_name = "accessible-name";
-static const gchar* atk_object_name_property_description = "accessible-description";
-static const gchar* atk_object_name_property_parent = "accessible-parent";
-static const gchar* atk_object_name_property_value = "accessible-value";
-static const gchar* atk_object_name_property_role = "accessible-role";
-static const gchar* atk_object_name_property_component_layer = "accessible-component-layer";
-static const gchar* atk_object_name_property_component_mdi_zorder = "accessible-component-mdi-zorder";
-static const gchar* atk_object_name_property_table_caption = "accessible-table-caption";
-static const gchar* atk_object_name_property_table_column_description = "accessible-table-column-description";
-static const gchar* atk_object_name_property_table_column_header = "accessible-table-column-header";
-static const gchar* atk_object_name_property_table_row_description = "accessible-table-row-description";
-static const gchar* atk_object_name_property_table_row_header = "accessible-table-row-header";
-static const gchar* atk_object_name_property_table_summary = "accessible-table-summary";
-static const gchar* atk_object_name_property_table_caption_object = "accessible-table-caption-object";
-static const gchar* atk_object_name_property_hypertext_num_links = "accessible-hypertext-nlinks";
+static const gchar* const atk_object_name_property_name = "accessible-name";
+static const gchar* const atk_object_name_property_description = "accessible-description";
+static const gchar* const atk_object_name_property_parent = "accessible-parent";
+static const gchar* const atk_object_name_property_value = "accessible-value";
+static const gchar* const atk_object_name_property_role = "accessible-role";
+static const gchar* const atk_object_name_property_component_layer = "accessible-component-layer";
+static const gchar* const atk_object_name_property_component_mdi_zorder = "accessible-component-mdi-zorder";
+static const gchar* const atk_object_name_property_table_caption = "accessible-table-caption";
+static const gchar* const atk_object_name_property_table_column_description = "accessible-table-column-description";
+static const gchar* const atk_object_name_property_table_column_header = "accessible-table-column-header";
+static const gchar* const atk_object_name_property_table_row_description = "accessible-table-row-description";
+static const gchar* const atk_object_name_property_table_row_header = "accessible-table-row-header";
+static const gchar* const atk_object_name_property_table_summary = "accessible-table-summary";
+static const gchar* const atk_object_name_property_table_caption_object = "accessible-table-caption-object";
+static const gchar* const atk_object_name_property_hypertext_num_links = "accessible-hypertext-nlinks";
 
 #ifdef G_OS_WIN32
 
@@ -240,11 +240,21 @@ static const gchar* atk_object_name_property_hypertext_num_links = "accessible-h
 
 G_WIN32_DLLMAIN_FOR_DLL_NAME(static, dll_name)
 
-static char *
+static const char *
 get_atk_locale_dir (void)
 {
-  return g_win32_get_package_installation_subdirectory
-    (GETTEXT_PACKAGE, dll_name, "lib/locale");
+  static gchar *atk_localedir = NULL;
+
+  if (!atk_localedir)
+    {
+      gchar *temp;
+
+      temp = g_win32_get_package_installation_subdirectory
+        (GETTEXT_PACKAGE, dll_name, "lib\\locale");
+      atk_localedir = g_win32_locale_filename_from_utf8 (temp);
+      g_free (temp);
+    }
+  return atk_localedir;
 }
 
 #endif
@@ -727,9 +737,9 @@ atk_object_get_role (AtkObject *accessible)
  *
  * Gets the layer of the accessible.
  *
- * Returns: an #AtkLayer which is the layer of the accessible
- *
  * @Deprecated: Use atk_component_get_layer instead.
+ *
+ * Returns: an #AtkLayer which is the layer of the accessible
  **/
 AtkLayer
 atk_object_get_layer (AtkObject *accessible) 
@@ -752,11 +762,12 @@ atk_object_get_layer (AtkObject *accessible)
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
  *
+ * @Deprecated: Use atk_component_get_mdi_zorder instead.
+ *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
  * container.
  *
- * @Deprecated: Use atk_component_get_mdi_zorder instead.
  **/
 gint
 atk_object_get_mdi_zorder (AtkObject *accessible) 
@@ -998,17 +1009,17 @@ atk_object_notify_state_change (AtkObject *accessible,
  * Returns: a reference to an object's #AtkObject implementation
  */
 AtkObject *
-atk_implementor_ref_accessible (AtkImplementor *object)
+atk_implementor_ref_accessible (AtkImplementor *implementor)
 {
   AtkImplementorIface *iface;
   AtkObject           *accessible = NULL;
 
-  g_return_val_if_fail (ATK_IS_IMPLEMENTOR (object), NULL);
+  g_return_val_if_fail (ATK_IS_IMPLEMENTOR (implementor), NULL);
 
-  iface = ATK_IMPLEMENTOR_GET_IFACE (object);
+  iface = ATK_IMPLEMENTOR_GET_IFACE (implementor);
 
   if (iface != NULL) 
-    accessible =  iface->ref_accessible (object);
+    accessible =  iface->ref_accessible (implementor);
 
   g_return_val_if_fail ((accessible != NULL), NULL);
 
@@ -1017,11 +1028,18 @@ atk_implementor_ref_accessible (AtkImplementor *object)
 
     	
 /**
+ * atk_object_get_attributes:
+ * @accessible: An #AtkObject.
+ *
  * Get a list of properties applied to this object as a whole, as an #AtkAttributeSet consisting of 
  * name-value pairs. As such these attributes may be considered weakly-typed properties or annotations, 
  * as distinct from strongly-typed object data available via other get/set methods.
  * Not all objects have explicit "name-value pair" #AtkAttributeSet properties.
+ *
  * @Since ATK 1.12
+ *
+ * Returns: an #AtkAttributeSet consisting of all explicit properties/annotations applied to 
+ * the object, or an empty set if the object has no name-value pair attributes assigned to it.
  */
 AtkAttributeSet *
 atk_object_get_attributes (AtkObject                  *accessible)
